@@ -2,28 +2,14 @@
 #
 #         PySceneDetect: Python-Based Video Scene Detector
 #   ---------------------------------------------------------------
-#     [  Site: http://www.bcastell.com/projects/PySceneDetect/   ]
+#     [  Site:   http://www.scenedetect.scenedetect.com/         ]
+#     [  Docs:   http://manual.scenedetect.scenedetect.com/      ]
 #     [  Github: https://github.com/Breakthrough/PySceneDetect/  ]
-#     [  Documentation: http://pyscenedetect.readthedocs.org/    ]
 #
-# Copyright (C) 2014-2021 Brandon Castellano <http://www.bcastell.com>.
+# Copyright (C) 2014-2022 Brandon Castellano <http://www.bcastell.com>.
+# PySceneDetect is licensed under the BSD 3-Clause License; see the
+# included LICENSE file, or visit one of the above pages for details.
 #
-# PySceneDetect is licensed under the BSD 3-Clause License; see the included
-# LICENSE file, or visit one of the following pages for details:
-#  - https://github.com/Breakthrough/PySceneDetect/
-#  - http://www.bcastell.com/projects/PySceneDetect/
-#
-# This software uses Numpy, OpenCV, click, pytest, mkvmerge, and ffmpeg. See
-# the included LICENSE-* files, or one of the above URLs for more information.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
-# AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-
 """ ``scenedetect.detectors.motion_detector`` Module
 
 This module implements the :py:class:`MotionDetector`, which detects motion events
@@ -39,6 +25,7 @@ import cv2
 # PySceneDetect Library Imports
 from scenedetect.scene_detector import SparseSceneDetector
 
+
 class MotionDetector(SparseSceneDetector):
     """Detects motion events in scenes containing a static background.
 
@@ -56,8 +43,8 @@ class MotionDetector(SparseSceneDetector):
             Setting to -1 (default) will auto-compute based on video resolution
             (typically 3 for SD, 5-7 for HD). Must be an odd integer > 1.
     """
-    def __init__(self, threshold = 0.50, num_frames_post_scene = 30,
-                 kernel_size = -1):
+
+    def __init__(self, threshold=0.50, num_frames_post_scene=30, kernel_size=-1):
         """Initializes motion-based scene detector object."""
         # TODO: Requires porting to v0.5 API.
         raise NotImplementedError()
@@ -109,5 +96,3 @@ class MotionDetector(SparseSceneDetector):
         return self.in_motion_event
         """
         return []
-
-
